#
# spec file for package python-jupyter-core
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%bcond_without python2
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
Name:           python-jupyter-core%{psuffix}
Version:        4.6.3
Release:        lp152.3.1
Summary:        Base package on which Jupyter projects rely
License:        BSD-3-Clause
URL:            https://github.com/jupyter/jupyter_core
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter_core/jupyter_core-%{version}.tar.gz
# PATCH-FIX-OPENSUSE -- use_rpms_paths.patch -- change paths so they are easy to replace at build time
Patch0:         use_rpms_paths.patch
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traitlets}
BuildRequires:  fdupes
BuildRequires:  jupyter-jupyter_core-filesystem
BuildRequires:  python-rpm-macros
Requires:       jupyter-jupyter_core = %{version}
Requires:       python-ipython_genutils
Requires:       python-traitlets
Recommends:     python-ipython
Provides:       python-jupyter_core = %{version}
Obsoletes:      python-jupyter_core < %{version}
BuildArch:      noarch
%ifpython2
Provides:       %{oldpython}-jupyter_core = %{version}
Obsoletes:      %{oldpython}-jupyter_core < %{version}
%endif
%if %{with test}
BuildRequires:  %{python_module jupyter-core}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest}
%if %{with python2}
BuildRequires:  python-mock
%endif
%endif
%python_subpackages

%description
Core common functionality of Jupyter projects.

This package contains base application classes and configuration inherited by
other projects. It doesn't do much on its own.

There is no reason to install this package on its own.  It will be pulled in
as a dependency by packages that require it.

This package provides the python interface.

%package     -n jupyter-jupyter-core
Summary:        Base package on which Jupyter projects rely
Requires:       jupyter-notebook-filesystem
Requires:       python3-jupyter-core = %{version}
Provides:       jupyter-jupyter_core = %{version}
Obsoletes:      jupyter-jupyter_core < %{version}
Provides:       jupyter-jupyter-core-doc = %{version}
Obsoletes:      jupyter-jupyter-core-doc < %{version}

%description -n jupyter-jupyter-core
Core common functionality of Jupyter projects.

This package contains base application classes and configuration inherited by
other projects. It doesn't do much on its own.

There is no reason to install this package on its own.  It will be pulled in
as a dependency by packages that require it.

This package provides the jupyter components.

%prep
%setup -q -n jupyter_core-%{version}
%patch0 -p1
# Set the appropriate paths dynamically
sed -i "s|\"%{_datadir}/jupyter\"|\"%{_datadir}/jupyter\"|" jupyter_core/paths.py
sed -i "s|\"%{_sysconfdir}/jupyter\"|\"%{_sysconfdir}/jupyter\"|" jupyter_core/paths.py
sed -i "s|(sys\.prefix, 'share', 'jupyter')|('%{_datadir}', 'jupyter')|" jupyter_core/paths.py
sed -i "s|(sys\.prefix, 'etc', 'jupyter')|('%{_sysconfdir}', 'jupyter')|" jupyter_core/paths.py

%build
%python_build

%install
%if !%{with test}
%python_install

%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/jupyter_core/troubleshoot.py
sed -i "s|^#!%{_bindir}/env python$|#!%{__$python}|" %{buildroot}%{$python_sitelib}/jupyter_core/troubleshoot.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/jupyter_core/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/jupyter_core/
%fdupes %{buildroot}%{$python_sitelib}
}
%endif

%if %{with test}
%check
# test_migrate requires files not found in the package
pushd jupyter_core/tests
rm test_migrate.py
%pytest
popd
%endif

%if !%{with test}
%files %{python_files}
%license COPYING.md
%{python_sitelib}/jupyter.py*
%pycache_only %{python_sitelib}/__pycache__/jupyter.*.py*
%{python_sitelib}/jupyter_core/
%{python_sitelib}/jupyter_core-%{version}-*.egg-info

%files -n jupyter-jupyter-core
%license COPYING.md
%doc CONTRIBUTING.md README.md
%{_bindir}/jupyter
%{_bindir}/jupyter-migrate
%{_bindir}/jupyter-troubleshoot
%endif

%changelog
* Sat Mar 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Mar 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull sybmol named package but real named package
* Mon Feb 24 2020 Todd R <toddrme2178@gmail.com>
- Update to 4.6.3
  * Changed windows secure_write path to skip all filesystem
    permission checks when running in insecure mode. Too many
    exception paths existed for mounted file systems to reliably
    try to set them before opting out with the insecure write
    pattern.
- Update to 4.6.2
  * Add ability to allow insecure writes with
    JUPYTER_ALLOW_INSECURE_WRITES environement variable.
  * Docs typo and build fixes
  * Added python 3.7 and 3.8 builds to testing
- Implement tests via multibuild
- Drop doc subpackage.  This was only around to resolve dependency
  cycles in testing, which the multibuild now does.  Keeping up
  with rapid changes in readthedocs was becoming difficult.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.6.1
  * Tolerate execute bit in owner permissions when validating secure writes
  * Fix project name typo in copyright
- Update to 4.6.0
  * Unicode characters existing in the user's home directory name are properly
    handled
  * ``mock`` is now only required for testing on Python 2
  * Deprecation warnings relative to ``_runtime_dir_changed`` are no longer
    produced
  * The ``scripts`` directory relative to the current python environment is
    now appended to the search directory for subcommands
  * Some utility functions (``exists()``, ``is_hidden()``, ``secure_write()``)
    have been moved from ``jupyter_client`` and ``jupyter_server`` to
    ``jupyter_core``
  * Fix error on Windows when setting private permissions
- Rename to python-jupyter-core to match upstream name change
* Fri Aug 16 2019 Todd R <toddrme2178@gmail.com>
- Fix self-obseletion
* Mon Jun 24 2019 Todd R <toddrme2178@gmail.com>
- Update to version 4.5.0
  * ``jupyter --version`` now tries to show the version number of various other
    installed Jupyter packages, not just ``jupyter_core``.
    This will hopefully make it clearer that there are various packages with
    their own version numbers.
  * Allow a :envvar:`JUPYTER_CONFIG_PATH` environment variable to specify a
    search path of additional locations for config.
  * ``jupyter subcommand`` no longer modifies the :envvar:`PATH` environment
    variable when it runs ``jupyter-subcommand``.
  * Jupyter's 'runtime' directory no longer uses ``XDG_RUNTIME_DIR``. While
    it has some attractive properties, it has led to various problems.
  * Fix ``JupyterApp`` to respect the ``raise_config_file_errors`` traitlet.
  * Various improvements to the bash completion scripts in this repository.
  * The ``setup.py`` script now always uses setuptools, like most other Jupyter
    projects.
  * The LICENSE file is included in wheels.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Split out jupyter components into subpackage.
- Add rpm macros.
- Rename doc package to match jupyter package.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Wed Nov 22 2017 arun@gmx.de
- require sphinxcontrib-github-alt
- update to version 4.4.0:
  * jupyter troubleshoot gets the list of packages from the Python
    environment it's in, by using sys.executable to call pip list
    (:ghpull:`104`).
  * Added utility function ensure_dir_exists, and switched to using it
    over the one from ipython_genutils, which does permissions wrong
    (:ghpull:`113`).
  * Avoid creating the ~/.ipython directory when checking if it exists
    for config migration (:ghpull:`118`).
  * Fix mistaken description in zsh completions (:ghpull:`98`).
  * Fix subcommand tests on Windows (:ghpull:`103`).
  * The README now describes how to work on jupyter_core and build the
    docs (:ghpull:`110`).
  * Fix a broken link to a release in the docs (:ghpull:`109`).
* Wed Sep 20 2017 toddrme2178@gmail.com
- Set configuration and data paths to be correct for any
  Linux distribution. This is done by using sed to replace
  hard-coded values with those provided by rpm.
  * Add use_rpms_paths.patch to make the paths easier to replace.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Remove version_specific_dirs.patch.
  The Python3 jupyter implementation will be used for directories.
* Fri Mar 31 2017 toddrme2178@gmail.com
- Add version_specific_dirs.patch
  Uses python version-specific directories to avoid conflicts.
- Install the directories used for system-side settings and data so
  they are properly owned by this package.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3.0
  * Add `JUPYTER_NO_CONFIG` environment variable for disabling all
    Jupyter configuration.
  * More detailed error message when failing to launch subcommands.
- Update to 4.2.1
  * Fix error message on Windows when subcommand not found.
  * Correctly display PATH in ``jupyter troubleshoot`` on Windows.
- Update to 4.2.0
  * Make :command:`jupyter` directory top priority in search path
    for subcommands, so that :command:`jupyter-subcommand` next to
    :command:`jupyter` will always be picked if present.
  * Avoid using ``shell=True`` for subcommand dispatch on Windows.
- Update to 4.1.1
  * Include symlink directory and real location on subcommand PATH
    when :file:`jupyter` is a symlink.
- Update to 4.1.0
  * Add ``jupyter.py`` module, so that :command:`python -m jupyter`
    always works.
  * Add prototype ``jupyter troubleshoot`` command for displaying
    environment info.
  * Ensure directory containing ``jupyter`` executable is included
    when dispatching subcommands.
  * Unicode fixes for Legacy Python.
* Wed Feb 17 2016 toddrme2178@gmail.com
- Simplify the tests for whether to build pdf documentation
* Wed Feb 17 2016 toddrme2178@gmail.com
- Split documentation to speed up building.
  This is a dependency of a lot of other packages, and the
  dependencies for the documentation are very heavy.  So build
  the documentation separately to avoid holding up the build
  process.
* Thu Oct  1 2015 toddrme2178@gmail.com
- Build documentation
* Wed Sep 23 2015 toddrme2178@gmail.com
- update to version 4.0.6:
  * fix typo preventing migration when custom.css is missing
- update to version 4.0.5:
  * fix subcommands on Windows (yes, again)
  * fix migration when custom.js/css are not present
* Mon Aug 24 2015 toddrme2178@gmail.com
- Update to 4.0.4
  * ensure version is printed to stdout …
  * remove file-extension from subcommand list on Windows
- Update requirements
* Fri Aug 14 2015 toddrme2178@gmail.com
- Update to 4.0.3
  * use raw_input on Python 2
  * Use setuptools entry points when setuptools in use
  * Use instances of traits instead of trait classes
- Fix package naming consistency
* Fri Aug 14 2015 toddrme2178@gmail.com
- Fix update-alternatives usage
* Thu Aug 13 2015 toddrme2178@gmail.com
- Update dependency names
* Tue Jul 21 2015 jennings@neuro.bzm
- Initial version
